@@ -48,10 +48,9 @@ docker_ignore_add <- function(path) {
       path_ri
     )) {
       write(
-        "^\\.dockerignore$",
-        path_ri,
-        append = TRUE
-      )
+        "^\\.dockerignore$", 
+        path_ri, 
+        append = TRUE)
       cat_bullet(
         ".dockerignore added to the .Rbuildignore file.",
         bullet = "info",
@@ -67,4 +66,4 @@ docker_ignore_add <- function(path) {
   }
 
   return(invisible(path_di))
-}
+}
\ No newline at end of file
